==> TradeGate-Beta-0.1.2b0.tar.gz: TradeGate-Beta-0.1.2b0/TradeGates/Watchers/futureOrderWatchers.py <==
import time


def watchFuturesLimitTrigger(gate, symbol, orderId, doPutTpSl, cancelIfNotOpened, params):
    if doPutTpSl:
        if 'tpSlOrderSide' not in params.keys() or 'stopLoss' not in params.keys() or 'takeProfit' not in params.keys():
            raise ValueError('Must specify \'tpSlOrderSide\' and \'stopLoss\' and \'takeProfit\'')

    if cancelIfNotOpened:
        if 'timeFrame' not in params.keys() or 'delayNum' not in params.keys():
            raise ValueError('Must specify \'timeFrame\' and \'delayNum\'')

    print('Watching order')
    while True:
        time.sleep(0.1)
        order = gate.getOrder(symbol=symbol, orderId=orderId, futures=True)
        if order['status'] == 'NEW':
            continue
        elif order['status'] == 'FILLED':
            if doPutTpSl:
                orderSide = params['tpSlOrderSide']
                stopLoss = params['stopLoss']
                takeProfit = params['takeProfit']

                stopLossOrder = gate.createAndTestFuturesOrder(symbol, orderSide, 'STOP_MARKET',
                                                               stopPrice=stopLoss, closePosition=True,
                                                               priceProtect=True, workingType='MARK_PRICE',
                                                               timeInForce='GTC')

                takeProfitOrder = gate.createAndTestFuturesOrder(symbol, orderSide, 'TAKE_PROFIT_MARKET',
                                                                 closePosition=True, stopPrice=takeProfit,
                                                                 priceProtect=True, workingType='MARK_PRICE',
                                                                 timeInForce='GTC')
                result = gate.makeBatchFuturesOrder([stopLossOrder, takeProfitOrder])
                print(result)
                break
        elif order['status'] == 'CANCELED':
            break

    print('Watching position')
    while True:
        time.sleep(0.1)
        position = gate.getPositionInfo(symbol)[0]

        if float(position['entryPrice']) == 0.0:
            gate.cancelAllSymbolOpenOrders(symbol, futures=True)
            break

==> TradeGate-Beta-0.1.5b2.tar.gz: TradeGate-Beta-0.1.5b2/TradeGates/Watchers/futureOrderWatchers.py <==
import time


def watchFuturesLimitTrigger(gate, symbol, orderId, doPutTpSl, cancelIfNotOpened, params):
    if doPutTpSl:
        if 'tpSlOrderSide' not in params.keys() or 'stopLoss' not in params.keys() or 'takeProfit' not in params.keys():
            raise ValueError('Must specify \'tpSlOrderSide\' and \'stopLoss\' and \'takeProfit\'')

    if cancelIfNotOpened:
        if 'cancelDelayMin' not in params.keys():
            raise ValueError('Must specify \'cancelDelayMin\'')
        delayTimeSec = float(params['cancelDelayMin']) * 60
        startDelayTime = time.time()

    print('Watching order')
    while True:
        time.sleep(0.1)
        order = gate.getOrder(symbol=symbol, orderId=orderId, futures=True)
        if order['status'] == 'NEW':
            continue
        elif order['status'] == 'FILLED':
            if doPutTpSl:
                orderSide = params['tpSlOrderSide']
                stopLoss = params['stopLoss']
                takeProfit = params['takeProfit']

                stopLossOrder = gate.createAndTestFuturesOrder(symbol, orderSide, 'STOP_MARKET',
                                                               stopPrice=str(stopLoss), closePosition=True,
                                                               priceProtect=True, workingType='MARK_PRICE',
                                                               timeInForce='GTC')

                takeProfitOrder = gate.createAndTestFuturesOrder(symbol, orderSide, 'TAKE_PROFIT_MARKET',
                                                                 stopPrice=str(takeProfit), closePosition=True,
                                                                 priceProtect=True, workingType='MARK_PRICE',
                                                                 timeInForce='GTC')
                result = gate.makeBatchFuturesOrder([stopLossOrder, takeProfitOrder])
                print(result)
                break
        elif order['status'] == 'CANCELED':
            break

        if cancelIfNotOpened:
            if time.time() - startDelayTime > delayTimeSec:
                gate.cancelOrder(symbol, orderId=orderId, futures=True)

    print('Watching position')
    while True:
        time.sleep(0.1)
        position = gate.getPositionInfo(symbol)[0]

        if float(position['entryPrice']) == 0.0:
            gate.cancelAllSymbolOpenOrders(symbol, futures=True)
            break
